@@ -23,6 +23,10 @@ FLATPAK_EXTERN GType flatpak_storage_type_get_type (void) G_GNUC_CONST;
 /* enumerations from "lib/flatpak-ref.h" */
 FLATPAK_EXTERN GType flatpak_ref_kind_get_type (void) G_GNUC_CONST;
 #define FLATPAK_TYPE_REF_KIND (flatpak_ref_kind_get_type ())
+
+/* enumerations from "lib/flatpak-remote.h" */
+FLATPAK_EXTERN GType flatpak_remote_type_get_type (void) G_GNUC_CONST;
+#define FLATPAK_TYPE_REMOTE_TYPE (flatpak_remote_type_get_type ())
 G_END_DECLS
 
 #endif /* __GIO_ENUM_TYPES_H__ */
